/*
** Module   : XmlSchema.java
** Abstract : Define getter and setter for SCHEMA-LOCATION attribute
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVK 20130508 Created initial version.
** 002 EVL 20130930 Adding legacy attributes and methods annotation.
** 003 EVL 20131009 Moved annotation for SCHEMA-LOCATION and SCHEMA-PATH here instead of upper
**                  interface
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Defines the SCHEMA-LOCATION and SCHEMA-PATH attribute.
 */
public interface XmlSchema
{
   /**
    * Determines the list of namespace/location pairs of an XML Schema file to validate
    * against.
    *
    * @param    schemaLocation
    *           Determines the list of namespace/location pairs of an XML Schema file to
    *           validate against.
    */
   @LegacyAttribute(name = "SCHEMA-LOCATION", setter = true)
   public void setSchemaLocation(character schemaLocation);

   /**
    * Determines the list of namespace/location pairs of an XML Schema file to validate
    * against.
    *
    * @return   schema location, default value is "".
    */
   @LegacyAttribute(name = "SCHEMA-LOCATION")
   public character getSchemaLocation();

   /**
    * A delimiter-separated list of directory paths used to locate the XML Document Type
    * Definition (DTD) associated with a particular XML document. It is searched if the XML
    * document contains a relative path to the DTD.
    *
    * @param    schemaPath
    *           To separate directory paths, use a comma, or a delimiter character that your
    *           operating system recognizes.
    */
   @LegacyAttribute(name = "SCHEMA-PATH", setter = true)
   public void setSchemaPath(character schemaPath);

   /**
    * A delimiter-separated list of directory paths used to locate the XML Document Type
    * Definition (DTD) associated with a particular XML document. It is searched if the XML
    * document contains a relative path to the DTD.
    *
    * @return   schema path, default value is unknown(?).
    */
   @LegacyAttribute(name = "SCHEMA-PATH")
   public character getSchemaPaths();

   /**
    * Indicates if the namespace processing is suppressed or not.
    *
    * @return   The logical value representing the current suppress-namespace-processing
    *           attribute.
    */
   @LegacyAttribute(name = "SUPPRESS-NAMESPACE-PROCESSING")
   public logical getSuppressNamespaceProcessing();

   /**
    * Redefines whether the namespace processing is suppressed or not.
    *
    * @param    suppress
    *           The new value the current suppress-namespace-processing attribute.
    */
   @LegacyAttribute(name = "SUPPRESS-NAMESPACE-PROCESSING", setter = true)
   public void setSuppressNamespaceProcessing(logical suppress);

   /**
    * Redefines whether the namespace processing is suppressed or not.
    *
    * @param    suppress
    *           The new value the current suppress-namespace-processing attribute.
    */
   @LegacyAttribute(name = "SUPPRESS-NAMESPACE-PROCESSING", setter = true)
   public void setSuppressNamespaceProcessing(boolean suppress);
}
